@@ -20,25 +20,45 @@ def get_slug_from_remote_url(remote_url: str) -> str:
     return potential_slug.removesuffix(".git")
 
 
+def get_current_branch(repo: Repo) -> Head:
+    remote = repo.remote("origin")
+    if repo.head.is_detached:
+        from_branch = next(
+            (branch for branch in remote.refs if branch.commit == repo.head.commit and branch.remote_head != "HEAD"),
+            None,
+        )
+    else:
+        from_branch = repo.active_branch
+
+    if from_branch is None:
+        raise ValueError(
+            "Could not determine the current branch."
+            "Make sure repository is not in a detached HEAD state with additional commits."
+        )
+
+    return from_branch
+
+
 @contextlib.contextmanager
 def transitioning_branches(
     repo: Repo, branch_prefix: str, branch_suffix: str = "", force: bool = True
-) -> Generator[tuple[Head, Head], None, None]:
-    from_branch = repo.active_branch
-    final_func = from_branch.checkout
-
-    next_branch_name = f"{branch_prefix}{from_branch.name}{branch_suffix}"
+) -> Generator[tuple[str, str], None, None]:
+    from_branch = get_current_branch(repo)
+    from_branch_name = from_branch.name if not from_branch.is_remote() else from_branch.remote_head
+    next_branch_name = f"{branch_prefix}{from_branch_name}{branch_suffix}"
     if next_branch_name in repo.heads and not force:
-        raise ValueError(f'Branch "{next_branch_name}" already exists.')
+        raise ValueError(f'Local Branch "{next_branch_name}" already exists.')
+    if next_branch_name in repo.remote("origin").refs and not force:
+        raise ValueError(f'Remote Branch "{next_branch_name}" already exists.')
 
     logger.info(f'Creating new branch "{next_branch_name}".')
     to_branch = repo.create_head(next_branch_name, force=force)
 
     try:
         to_branch.checkout()
-        yield from_branch, to_branch
+        yield from_branch_name, next_branch_name
     finally:
-        final_func()
+        from_branch.checkout()
 
 
 class _EphemeralGitConfig:
@@ -129,7 +149,9 @@ class CommitChanges(Step):
         repo = git.Repo(Path.cwd())
         if not self.enabled:
             logger.debug("Branch creation is disabled.")
-            return dict(target_branch=repo.active_branch.name)
+            from_branch = get_current_branch(repo)
+            from_branch_name = from_branch.name if not from_branch.is_remote() else from_branch.remote_head
+            return dict(target_branch=from_branch_name)
 
         modified_files = {modified_code_file["path"] for modified_code_file in self.modified_code_files}
 
@@ -145,6 +167,6 @@ class CommitChanges(Step):
 
             logger.info(f"Run completed {self.__class__.__name__}")
             return dict(
-                base_branch=from_branch.name,
-                target_branch=to_branch.name,
+                base_branch=from_branch,
+                target_branch=to_branch,
             )
